@@ -609,6 +609,8 @@ void determine_theme_type (void)
     }
 
     if (at_startup || !STREQ (ks.red_hue, old_color)) {
+        const gchar *right_to_left = (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL) ? "&#8207;" : "";
+    
         ks.blue_hue = (ks.bg_image_or_gradient) ? "blue" : ((!ks.dark_theme) ? "darkblue" : "lightblue");
 
         g_string_printf (ks.label_field_txt, _(" Label (<span foreground='%s'>*</span>): "), ks.red_hue);
@@ -618,9 +620,12 @@ void determine_theme_type (void)
         else {
             g_string_assign (ks.menu_ID_field_txt, _(" Menu ID: "));
         }
-        g_string_printf (ks.execute_field_txt, " Execute (<span foreground='%s'>*</span>): ", ks.red_hue);
-        g_string_printf (ks.prompt_field_txt, " Prompt (<span foreground='%s'>*</span>): ", ks.red_hue);
-        g_string_printf (ks.command_field_txt, " Command (<span foreground='%s'>*</span>): ", ks.red_hue);
+        // In the case that a right-to-left script is used the following three need the &#8207 entity inserted, 
+        // because otherwise the colon will not set to the left of the text.
+        // For the label texts above it works without, because there are translations.
+        g_string_printf (ks.execute_field_txt, "%s Execute (<span foreground='%s'>*</span>): ", right_to_left, ks.red_hue);
+        g_string_printf (ks.prompt_field_txt, "%s Prompt (<span foreground='%s'>*</span>): ", right_to_left, ks.red_hue);
+        g_string_printf (ks.command_field_txt, "%s Command (<span foreground='%s'>*</span>): ", right_to_left, ks.red_hue);
         g_string_printf (ks.mandatory_label_txt, "(<span foreground='%s'>*</span>) = %s", ks.red_hue, _("mandatory"));
         g_string_printf (ks.mandatory_empty_string_txt, "(<span foreground='%s'>*</span>) = %s; "
                                                         "(<span foreground='%s'>*</span>) = %s",
