@@ -29,7 +29,7 @@ def create_gresource_xml(file_name, include_pre_gtk3_20):
     root = ET.Element('gresources')
     gresource = ET.SubElement(root, 'gresource', prefix="/org/kickshaw/")
     
-    initial_files = ["imgs/logo_about_1.jpg", "imgs/logo_about_2.png", "imgs/logo_about_3.jpg", "txts/credits"]
+    initial_files = ["imgs/logo_about_1.jpg", "imgs/logo_about_2.png", "imgs/logo_about_3.jpg", "imgs/logo_about_4.png", "txts/credits"]
     for f in initial_files:
         ET.SubElement(gresource, 'file', compressed="true").text = f
 
